==> streamtuner-0.11.1.tar.gz: streamtuner-0.11.1/src/streamtuner/st-stream-menu-items.h <==
/*
 * $Id: st-stream-menu-items.h,v 1.12 2004/01/27 13:42:00 jylefort Exp $
 *
 * Copyright (c) 2003, 2004 Jean-Yves Lefort
 * All rights reserved.
 *
 * Redistribution and use in source and binary forms, with or without
 * modification, are permitted provided that the following conditions
 * are met:
 * 1. Redistributions of source code must retain the above copyright
 *    notice, this list of conditions and the following disclaimer.
 * 2. Redistributions in binary form must reproduce the above copyright
 *    notice, this list of conditions and the following disclaimer in the
 *    documentation and/or other materials provided with the distribution.
 * 3. Neither the name of Jean-Yves Lefort nor the names of its contributors
 *    may be used to endorse or promote products derived from this software
 *    without specific prior written permission.
 *
 * THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND
 * CONTRIBUTORS "AS IS" AND ANY EXPRESS OR IMPLIED WARRANTIES,
 * INCLUDING, BUT NOT LIMITED TO, THE IMPLIED WARRANTIES OF
 * MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE
 * DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT OWNER OR CONTRIBUTORS
 * BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL,
 * EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED
 * TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE,
 * DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON
 * ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY,
 * OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY
 * OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE
 * POSSIBILITY OF SUCH DAMAGE.
 */

#ifndef _ST_STREAM_MENU_ITEMS_H
#define _ST_STREAM_MENU_ITEMS_H

#include <gtk/gtk.h>

typedef struct
{
  GtkWidget	*tune_in;
  GtkWidget	*record;
  GtkWidget	*browse;
  GtkWidget	*separator1;
  GtkWidget	*add_bookmark;
  GtkWidget	*remove_bookmark;
  GtkWidget	*separator2;
  GtkWidget	*properties;
} STStreamMenuItems;

STStreamMenuItems *st_stream_menu_items_new	(GtkAccelGroup *accel_group);

void st_stream_menu_items_update_sensitivity	(STStreamMenuItems  *items);

void st_stream_menu_items_append_to_shell	(STStreamMenuItems  *items,
						 GtkMenuShell	    *shell);
void st_stream_menu_items_prepend_to_shell	(STStreamMenuItems  *items,
						 GtkMenuShell	    *shell);

#endif /* _ST_STREAM_MENU_ITEMS_H */

==> streamtuner-0.12.0.tar.gz: streamtuner-0.12.0/src/streamtuner/st-stream-menu-items.h <==
/*
 * $Id: st-stream-menu-items.h,v 1.16 2004/03/07 08:22:00 jylefort Exp $
 *
 * Copyright (c) 2003, 2004 Jean-Yves Lefort
 * All rights reserved.
 *
 * Redistribution and use in source and binary forms, with or without
 * modification, are permitted provided that the following conditions
 * are met:
 * 1. Redistributions of source code must retain the above copyright
 *    notice, this list of conditions and the following disclaimer.
 * 2. Redistributions in binary form must reproduce the above copyright
 *    notice, this list of conditions and the following disclaimer in the
 *    documentation and/or other materials provided with the distribution.
 * 3. Neither the name of Jean-Yves Lefort nor the names of its contributors
 *    may be used to endorse or promote products derived from this software
 *    without specific prior written permission.
 *
 * THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND
 * CONTRIBUTORS "AS IS" AND ANY EXPRESS OR IMPLIED WARRANTIES,
 * INCLUDING, BUT NOT LIMITED TO, THE IMPLIED WARRANTIES OF
 * MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE
 * DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT OWNER OR CONTRIBUTORS
 * BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL,
 * EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED
 * TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE,
 * DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON
 * ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY,
 * OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY
 * OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE
 * POSSIBILITY OF SUCH DAMAGE.
 */

#ifndef _ST_STREAM_MENU_ITEMS_H
#define _ST_STREAM_MENU_ITEMS_H

#include <gtk/gtk.h>
#include "st-shell.h"

typedef struct _STStreamMenuItems STStreamMenuItems;

STStreamMenuItems *st_stream_menu_items_new (STShell		*shell,
					     GtkAccelGroup	*accel_group);
void              st_stream_menu_items_free (STStreamMenuItems	*items);

void st_stream_menu_items_update_sensitivity	(STStreamMenuItems  *items);

void st_stream_menu_items_append_to_shell	(STStreamMenuItems  *items,
						 GtkMenuShell	    *menu_shell);
void st_stream_menu_items_prepend_to_shell	(STStreamMenuItems  *items,
						 GtkMenuShell	    *menu_shell);

#endif /* _ST_STREAM_MENU_ITEMS_H */
